========================================
Yet Another Workflow Language for Python
========================================


.. image:: https://img.shields.io/pypi/v/pyyawl.svg
        :target: https://pypi.python.org/pypi/pyyawl

.. image:: https://img.shields.io/travis/fabiofumarola/pyyawl.svg
        :target: https://travis-ci.org/fabiofumarola/pyyawl

.. image:: https://readthedocs.org/projects/pyyawl/badge/?version=latest
        :target: https://pyyawl.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/fabiofumarola/pyyawl/shield.svg
     :target: https://pyup.io/repos/github/fabiofumarola/pyyawl/
     :alt: Updates



Yet another simple workflow language for python


* Free software: Apache Software License 2.0
* Documentation: https://pyyawl.readthedocs.io.


Features
--------

* execute worfkflow defined in yaml
* simple and extensible


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
